@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use base qw(Test::Class);
 use Test::More;
-use Date::Holidays::PRODUCERAL qw(holidays is_holiday);
+use Date::Holidays::Produceral qw(holidays is_holiday);
 
 my $day   = 24;
 my $month = 12;
@@ -13,8 +13,6 @@ my $year  = 2007;
 
 #run prior and once per suite
 sub startup : Test(startup => 1) {
-    diag("starting up...");
-
     use_ok('Date::Holidays');
 }
 
@@ -22,17 +20,17 @@ sub test_produceral_interface : Test(13) {
 
     # bare
 
-    use_ok('Date::Holidays::PRODUCERAL', qw(holidays is_holiday));
+    use_ok('Date::Holidays::Produceral', qw(holidays is_holiday));
 
-    can_ok('Date::Holidays::PRODUCERAL', qw(holidays is_holiday));
+    can_ok('Date::Holidays::Produceral', qw(holidays is_holiday));
 
-    ok(Date::Holidays::PRODUCERAL::holidays($year), 'calling holidays directly');
+    ok(Date::Holidays::Produceral::holidays($year), 'calling holidays directly');
 
-    is(Date::Holidays::PRODUCERAL::is_holiday($year, $month, $day), 'christmas', 'calling is_holiday directly');
+    is(Date::Holidays::Produceral::is_holiday($year, $month, $day), 'christmas', 'calling is_holiday directly');
 
     # wrapper
 
-    ok(my $dh = Date::Holidays->new(nocheck => 1, countrycode => 'produceral'), 'instantiating Date::Holidays');
+    ok(my $dh = Date::Holidays->new(nocheck => 1, countrycode => 'Produceral'), 'instantiating Date::Holidays');
     isa_ok($dh, 'Date::Holidays', 'checking wrapper object');
     can_ok($dh, qw(holidays is_holiday));
 
